==> drupalmoduleupgrader-8.x-0.7.tar.gz: drupalmoduleupgrader/src/Plugin/DMU/Converter/HookEntityTypeView.php <==
<?php

namespace Drupal\drupalmoduleupgrader\Plugin\DMU\Converter;

use Drupal\Component\Plugin\PluginManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\drupalmoduleupgrader\ConverterBase;
use Drupal\drupalmoduleupgrader\TargetInterface;
use Drupal\drupalmoduleupgrader\Utility\ParametricRewriter\PropertyAccessRewriter;
use Pharborist\Functions\ParameterNode;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * @Converter(
 *  id = "hook_ENTITY_TYPE_view",
 *  description = @Translation("Converts implementations of hook_ENTITY_TYPE_view()."),
 *  hook = {
 *    "comment_view",
 *    "node_view",
 *    "taxonomy_term_view",
 *    "user_view"
 *  }
 * )
 */
class HookEntityTypeView extends ConverterBase implements ContainerFactoryPluginInterface {

  /**
   * @var \Drupal\Component\Plugin\PluginManagerInterface
   */
  protected $rewriters;

  public function __construct(array $configuration, $plugin_id, $plugin_definition, PluginManagerInterface $rewriters) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->rewriters = $rewriters;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('plugin.manager.drupalmoduleupgrader.rewriter')
    );
  }

  public function convert(TargetInterface $target) {
    $indexer = $target->getIndexer('hook');

    $hooks = array_filter($this->pluginDefinition['hook'], [$indexer, 'has']);
    foreach ($hooks as $hook) {
      /** @var \Pharborist\Functions\FunctionDeclarationNode $function */
      $function = $indexer->get($hook)->get(0);
      $function->prependParameter(ParameterNode::create('build')->setTypeHint('array')->setReference(TRUE));

      $entity_type = subStr($hook, 0, strrPos($hook, '_'));
      $rewriter = $this->rewriters->createInstance('_rewriter:' . $entity_type);
      $this->rewriteFunction($rewriter, $function->getParameterAtIndex(1), $target);
    }
  }

}

==> drupalmoduleupgrader-8.x-1.0.tar.gz: drupalmoduleupgrader/src/Plugin/DMU/Converter/HookEntityTypeView.php <==
<?php

namespace Drupal\drupalmoduleupgrader\Plugin\DMU\Converter;

use Drupal\Component\Plugin\PluginManagerInterface;
use Drupal\Core\StringTranslation\TranslationInterface;
use Drupal\drupalmoduleupgrader\ConverterBase;
use Drupal\drupalmoduleupgrader\TargetInterface;
use Pharborist\Functions\ParameterNode;
use Psr\Log\LoggerInterface;

/**
 * @Converter(
 *  id = "hook_ENTITY_TYPE_view",
 *  description = @Translation("Converts implementations of hook_ENTITY_TYPE_view()."),
 *  hook = {
 *    "comment_view",
 *    "node_view",
 *    "taxonomy_term_view",
 *    "user_view"
 *  },
 *  dependencies = { "plugin.manager.drupalmoduleupgrader.rewriter" }
 * )
 */
class HookEntityTypeView extends ConverterBase {

  /**
   * @var \Drupal\Component\Plugin\PluginManagerInterface
   */
  protected $rewriters;

  public function __construct(array $configuration, $plugin_id, $plugin_definition, TranslationInterface $translator, LoggerInterface $log, PluginManagerInterface $rewriters) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $translator, $log);
    $this->rewriters = $rewriters;
  }

  public function convert(TargetInterface $target) {
    $indexer = $target->getIndexer('hook');

    $hooks = array_filter($this->pluginDefinition['hook'], [$indexer, 'has']);
    foreach ($hooks as $hook) {
      /** @var \Pharborist\Functions\FunctionDeclarationNode $function */
      $function = $indexer->get($hook)->get(0);
      $function->prependParameter(ParameterNode::create('build')->setTypeHint('array')->setReference(TRUE));

      $entity_type = subStr($hook, 0, strrPos($hook, '_'));
      $rewriter = $this->rewriters->createInstance('_rewriter:' . $entity_type);
      $this->rewriteFunction($rewriter, $function->getParameterAtIndex(1), $target);
    }
  }

}
